@@ -1,17 +1,7 @@
-# 
-# This file is part of Test-Reporter
-# 
-# This software is copyright (c) 2010 by Authors and Contributors.
-# 
-# This is free software; you can redistribute it and/or modify it under
-# the same terms as the Perl 5 programming language system itself.
-# 
 use strict;
 BEGIN{ if (not $] < 5.006) { require warnings; warnings->import } }
 package Test::Reporter::Transport;
-use vars qw/$VERSION/;
-$VERSION = '1.56';
-$VERSION = eval $VERSION;
+our $VERSION = '1.58'; # VERSION
 
 sub new     { die "Not implemented" }
 
@@ -19,17 +9,19 @@ sub send    { die "Not implemented" }
 
 1;
 
+# ABSTRACT: base class for Test::Reporter transports
+
 
 
 =pod
 
 =head1 NAME
 
-Test::Reporter::Transport
+Test::Reporter::Transport - base class for Test::Reporter transports
 
 =head1 VERSION
 
-version 1.56
+version 1.58
 
 =head1 SYNOPSIS
 
@@ -48,41 +40,32 @@ This module is an abstract base class that define an API for
 Test::Reporter::Transport subclasses.  Individual subclasses MUST 
 implement the methods described below.
 
-=head1 NAME
-
-Test::Reporter::Transport - base class for Test::Reporter transports
-
 =head1 USAGE
 
 A transport method is specified to Test::Reporter using the C<transport>
 option.  The C<transport> option expects just the module "suffix" that follows
 C<Test::Reporter::Transport>.  For example:
 
-    # use Test::Reporter::Transport::Net::SMTP for transport
+    # use Test::Reporter::Transport::Null for transport
     my $report = Test::Reporter->new(
-        transport => 'Net::SMTP'
-    );
-
-    # use Test::Reporter::Transport::Mail::Send for transport
-    my $report = Test::Reporter->new(
-        transport => 'Mail::Send'
+        transport => 'Null'
     );
 
 Configuration of the transport is specified with the C<transport_args>
 option:
 
     my $report = Test::Reporter->new(
-        transport => 'Net::SMTP::TLS',
-        transport_args => [ User => 'John', Password => '123' ],
+        transport => 'File',
+        transport_args => [ dir => '/tmp' ],
     );
 
 These may also be specified with the C<transport> or C<transport_args> methods:
 
-    $report->transport_args( User => 'John', Password => '123' );
+    $report->transport_args( dir => '/tmp' );
 
 These may also be combined in the C<transport> method itself:
 
-    $report->transport( 'Net::SMTP::TLS', User => 'John', Password => '123');
+    $report->transport( 'File', dir => '/tmp' );
 
 =head1 METHODS
 
@@ -104,20 +87,41 @@ is successfully created or undef if the object can not be created.
 The C<send> method MUST take a Test::Reporter object as its only argument.  It
 MUST return true if the report is successfully sent.  It SHOULD die with a
 message describing the failure if a report cannot be sent.  It MUST NOT return
-a true value if the report cannot be sent.  
+a true value if the report cannot be sent.
 
 =head1 AUTHORS
 
-  Adam J. Foxson <afoxson@pobox.com>
-  David Golden <dagolden@cpan.org>
-  Kirrily "Skud" Robert <skud@cpan.org>
-  Ricardo Signes <rjbs@cpan.org>
-  Richard Soderberg <rsod@cpan.org>
-  Kurt Starsinic <Kurt.Starsinic@isinet.com>
+=over 4
+
+=item *
+
+Adam J. Foxson <afoxson@pobox.com>
+
+=item *
+
+David Golden <dagolden@cpan.org>
+
+=item *
+
+Kirrily "Skud" Robert <skud@cpan.org>
+
+=item *
+
+Ricardo Signes <rjbs@cpan.org>
+
+=item *
+
+Richard Soderberg <rsod@cpan.org>
+
+=item *
+
+Kurt Starsinic <Kurt.Starsinic@isinet.com>
+
+=back
 
 =head1 COPYRIGHT AND LICENSE
 
-This software is copyright (c) 2010 by Authors and Contributors.
+This software is copyright (c) 2011 by Authors and Contributors.
 
 This is free software; you can redistribute it and/or modify it under
 the same terms as the Perl 5 programming language system itself.
